@@ -7,7 +7,9 @@ require 'rack/accept'
 require 'rack/auth/basic'
 require 'rack/auth/digest/md5'
 require 'set'
+require 'active_support'
 require 'active_support/version'
+require 'active_support/isolated_execution_state' if ActiveSupport::VERSION::MAJOR > 6
 require 'active_support/core_ext/hash/indifferent_access'
 require 'active_support/core_ext/object/blank'
 require 'active_support/core_ext/array/extract_options'
@@ -22,7 +24,7 @@ require 'active_support/dependencies/autoload'
 require 'active_support/notifications'
 require 'i18n'
 
-I18n.load_path << File.expand_path('../grape/locale/en.yml', __FILE__)
+I18n.load_path << File.expand_path('grape/locale/en.yml', __dir__)
 
 module Grape
   extend ::ActiveSupport::Autoload
@@ -76,6 +78,7 @@ module Grape
       autoload :InvalidVersionHeader
       autoload :MethodNotAllowed
       autoload :InvalidResponse
+      autoload :EmptyMessageBody
     end
   end
 
