@@ -10,12 +10,8 @@ module Grape
           result = wrap_message(present(message, env))
 
           rescue_options = options[:rescue_options] || {}
-          if rescue_options[:backtrace] && backtrace && !backtrace.empty?
-            result = result.merge(backtrace: backtrace)
-          end
-          if rescue_options[:original_exception] && original_exception
-            result = result.merge(original_exception: original_exception.inspect)
-          end
+          result = result.merge(backtrace: backtrace) if rescue_options[:backtrace] && backtrace && !backtrace.empty?
+          result = result.merge(original_exception: original_exception.inspect) if rescue_options[:original_exception] && original_exception
           ::Grape::Json.dump(result)
         end
 
