@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 module Grape
   module Parser
     module Xml
@@ -6,7 +8,7 @@ module Grape
           ::Grape::Xml.parse(object)
         rescue ::Grape::Xml::ParseError
           # handle XML parsing errors via the rescue handlers or provide error message
-          raise Grape::Exceptions::InvalidMessageBody, 'application/xml'
+          raise Grape::Exceptions::InvalidMessageBody.new('application/xml')
         end
       end
     end
