@@ -3,19 +3,17 @@
 require 'spec_helper'
 
 describe Grape::API::Helpers do
-  subject do
-    shared_params = Module.new do
-      extend Grape::API::Helpers
-
-      params :drink do
-        optional :beer
-        optional :wine
-        exactly_one_of :beer, :wine
-      end
-    end
-
+  let(:app) do
     Class.new(Grape::API) do
-      helpers shared_params
+      helpers Module.new do
+        extend Grape::API::Helpers
+
+        params :drink do
+          optional :beer
+          optional :wine
+          exactly_one_of :beer, :wine
+        end
+      end
       format :json
 
       params do
@@ -35,10 +33,6 @@ describe Grape::API::Helpers do
     end
   end
 
-  def app
-    subject
-  end
-
   it 'defines parameters' do
     get '/', orderType: 'food', pizza: 'mista'
     expect(last_response.status).to eq 200
