@@ -12,7 +12,8 @@ module Grape
 
     describe Middleware do
       subject { Class.new(MiddlewareSpec::Dummy) }
-      let(:proc) { ->() {} }
+
+      let(:proc) { -> {} }
       let(:foo_middleware) { Class.new }
       let(:bar_middleware) { Class.new }
 
