@@ -10,10 +10,10 @@ describe Grape::Extensions::Hashie::Mash::ParamBuilder do
   end
 
   describe 'in an endpoint' do
-    context '#params' do
+    describe '#params' do
       before do
         subject.params do
-          build_with Grape::Extensions::Hashie::Mash::ParamBuilder
+          build_with Grape::Extensions::Hashie::Mash::ParamBuilder # rubocop:disable RSpec/DescribedClass
         end
 
         subject.get do
@@ -21,7 +21,7 @@ describe Grape::Extensions::Hashie::Mash::ParamBuilder do
         end
       end
 
-      it 'should be of type Hashie::Mash' do
+      it 'is of type Hashie::Mash' do
         get '/'
         expect(last_response.status).to eq(200)
         expect(last_response.body).to eq('Hashie::Mash')
@@ -31,17 +31,17 @@ describe Grape::Extensions::Hashie::Mash::ParamBuilder do
 
   describe 'in an api' do
     before do
-      subject.send(:include, Grape::Extensions::Hashie::Mash::ParamBuilder)
+      subject.send(:include, Grape::Extensions::Hashie::Mash::ParamBuilder) # rubocop:disable RSpec/DescribedClass
     end
 
-    context '#params' do
+    describe '#params' do
       before do
         subject.get do
           params.class
         end
       end
 
-      it 'should be Hashie::Mash' do
+      it 'is Hashie::Mash' do
         get '/'
         expect(last_response.status).to eq(200)
         expect(last_response.body).to eq('Hashie::Mash')
@@ -57,7 +57,7 @@ describe Grape::Extensions::Hashie::Mash::ParamBuilder do
         end
       end
 
-      it 'should be Hashie::Mash' do
+      it 'is Hashie::Mash' do
         get '/foo'
         expect(last_response.status).to eq(200)
         expect(last_response.body).to eq('Hashie::Mash')
@@ -66,7 +66,7 @@ describe Grape::Extensions::Hashie::Mash::ParamBuilder do
 
     it 'is indifferent to key or symbol access' do
       subject.params do
-        build_with Grape::Extensions::Hashie::Mash::ParamBuilder
+        build_with Grape::Extensions::Hashie::Mash::ParamBuilder # rubocop:disable RSpec/DescribedClass
         requires :a, type: String
       end
       subject.get '/foo' do
