@@ -5,7 +5,7 @@ require 'spec_helper'
 describe Grape::Middleware::Auth::DSL do
   subject { Class.new(Grape::API) }
 
-  let(:block) { ->() {} }
+  let(:block) { -> {} }
   let(:settings) do
     {
       opaque: 'secret',
@@ -16,7 +16,7 @@ describe Grape::Middleware::Auth::DSL do
   end
 
   describe '.auth' do
-    it 'stets auth parameters' do
+    it 'sets auth parameters' do
       expect(subject.base_instance).to receive(:use).with(Grape::Middleware::Auth::Base, settings)
 
       subject.auth :http_digest, realm: settings[:realm], opaque: settings[:opaque], &settings[:proc]
@@ -38,16 +38,25 @@ describe Grape::Middleware::Auth::DSL do
   end
 
   describe '.http_basic' do
-    it 'stets auth parameters' do
+    it 'sets auth parameters' do
       subject.http_basic realm: 'my_realm', &settings[:proc]
       expect(subject.auth).to eq(realm: 'my_realm', type: :http_basic, proc: block)
     end
   end
 
   describe '.http_digest' do
-    it 'stets auth parameters' do
-      subject.http_digest realm: 'my_realm', opaque: 'my_opaque', &settings[:proc]
-      expect(subject.auth).to eq(realm: 'my_realm', type: :http_digest, proc: block, opaque: 'my_opaque')
+    context 'when realm is a hash' do
+      it 'sets auth parameters' do
+        subject.http_digest realm: { realm: 'my_realm', opaque: 'my_opaque' }, &settings[:proc]
+        expect(subject.auth).to eq(realm: { realm: 'my_realm', opaque: 'my_opaque' }, type: :http_digest, proc: block)
+      end
+    end
+
+    context 'when realm is not hash' do
+      it 'sets auth parameters' do
+        subject.http_digest realm: 'my_realm', opaque: 'my_opaque', &settings[:proc]
+        expect(subject.auth).to eq(realm: 'my_realm', type: :http_digest, proc: block, opaque: 'my_opaque')
+      end
     end
   end
 end
