@@ -5,7 +5,9 @@ require 'spec_helper'
 describe Grape::Middleware::Stack do
   module StackSpec
     class FooMiddleware; end
+
     class BarMiddleware; end
+
     class BlockMiddleware
       attr_reader :block
 
@@ -15,10 +17,10 @@ describe Grape::Middleware::Stack do
     end
   end
 
-  let(:proc) { ->() {} }
-  let(:others) { [[:use, StackSpec::BarMiddleware], [:insert_before, StackSpec::BarMiddleware, StackSpec::BlockMiddleware, proc]] }
+  subject { described_class.new }
 
-  subject { Grape::Middleware::Stack.new }
+  let(:proc) { -> {} }
+  let(:others) { [[:use, StackSpec::BarMiddleware], [:insert_before, StackSpec::BarMiddleware, StackSpec::BlockMiddleware, proc]] }
 
   before do
     subject.use StackSpec::FooMiddleware
@@ -27,20 +29,20 @@ describe Grape::Middleware::Stack do
   describe '#use' do
     it 'pushes a middleware class onto the stack' do
       expect { subject.use StackSpec::BarMiddleware }
-        .to change { subject.size }.by(1)
+        .to change(subject, :size).by(1)
       expect(subject.last).to eq(StackSpec::BarMiddleware)
     end
 
     it 'pushes a middleware class with arguments onto the stack' do
       expect { subject.use StackSpec::BarMiddleware, false, my_arg: 42 }
-        .to change { subject.size }.by(1)
+        .to change(subject, :size).by(1)
       expect(subject.last).to eq(StackSpec::BarMiddleware)
       expect(subject.last.args).to eq([false, { my_arg: 42 }])
     end
 
     it 'pushes a middleware class with block arguments onto the stack' do
       expect { subject.use StackSpec::BlockMiddleware, &proc }
-        .to change { subject.size }.by(1)
+        .to change(subject, :size).by(1)
       expect(subject.last).to eq(StackSpec::BlockMiddleware)
       expect(subject.last.args).to eq([])
       expect(subject.last.block).to eq(proc)
@@ -50,7 +52,7 @@ describe Grape::Middleware::Stack do
   describe '#insert' do
     it 'inserts a middleware class at the integer index' do
       expect { subject.insert 0, StackSpec::BarMiddleware }
-        .to change { subject.size }.by(1)
+        .to change(subject, :size).by(1)
       expect(subject[0]).to eq(StackSpec::BarMiddleware)
       expect(subject[1]).to eq(StackSpec::FooMiddleware)
     end
@@ -59,7 +61,7 @@ describe Grape::Middleware::Stack do
   describe '#insert_before' do
     it 'inserts a middleware before another middleware class' do
       expect { subject.insert_before StackSpec::FooMiddleware, StackSpec::BarMiddleware }
-        .to change { subject.size }.by(1)
+        .to change(subject, :size).by(1)
       expect(subject[0]).to eq(StackSpec::BarMiddleware)
       expect(subject[1]).to eq(StackSpec::FooMiddleware)
     end
@@ -68,7 +70,7 @@ describe Grape::Middleware::Stack do
       subject.use Class.new(StackSpec::BlockMiddleware)
 
       expect { subject.insert_before StackSpec::BlockMiddleware, StackSpec::BarMiddleware }
-        .to change { subject.size }.by(1)
+        .to change(subject, :size).by(1)
 
       expect(subject[1]).to eq(StackSpec::BarMiddleware)
       expect(subject[2]).to eq(StackSpec::BlockMiddleware)
@@ -83,7 +85,7 @@ describe Grape::Middleware::Stack do
   describe '#insert_after' do
     it 'inserts a middleware after another middleware class' do
       expect { subject.insert_after StackSpec::FooMiddleware, StackSpec::BarMiddleware }
-        .to change { subject.size }.by(1)
+        .to change(subject, :size).by(1)
       expect(subject[1]).to eq(StackSpec::BarMiddleware)
       expect(subject[0]).to eq(StackSpec::FooMiddleware)
     end
@@ -92,7 +94,7 @@ describe Grape::Middleware::Stack do
       subject.use Class.new(StackSpec::BlockMiddleware)
 
       expect { subject.insert_after StackSpec::BlockMiddleware, StackSpec::BarMiddleware }
-        .to change { subject.size }.by(1)
+        .to change(subject, :size).by(1)
 
       expect(subject[1]).to eq(StackSpec::BlockMiddleware)
       expect(subject[2]).to eq(StackSpec::BarMiddleware)
@@ -107,7 +109,7 @@ describe Grape::Middleware::Stack do
   describe '#merge_with' do
     it 'applies a collection of operations and middlewares' do
       expect { subject.merge_with(others) }
-        .to change { subject.size }.by(2)
+        .to change(subject, :size).by(2)
       expect(subject[0]).to eq(StackSpec::FooMiddleware)
       expect(subject[1]).to eq(StackSpec::BlockMiddleware)
       expect(subject[2]).to eq(StackSpec::BarMiddleware)
