@@ -1,9 +1,12 @@
+# frozen_string_literal: true
+
 require 'spec_helper'
 
 describe Grape::Middleware::Versioner::Param do
+  subject { described_class.new(app, **options) }
+
   let(:app) { ->(env) { [200, env, env['api.version']] } }
   let(:options) { {} }
-  subject { Grape::Middleware::Versioner::Param.new(app, options) }
 
   it 'sets the API version based on the default param (apiver)' do
     env = Rack::MockRequest.env_for('/awesome', params: { 'apiver' => 'v1' })
@@ -24,10 +27,12 @@ describe Grape::Middleware::Versioner::Param do
 
   context 'with specified parameter name' do
     let(:options) { { version_options: { parameter: 'v' } } }
+
     it 'sets the API version based on the custom parameter name' do
       env = Rack::MockRequest.env_for('/awesome', params: { 'v' => 'v1' })
       expect(subject.call(env)[1]['api.version']).to eq('v1')
     end
+
     it 'does not set the API version based on the default param' do
       env = Rack::MockRequest.env_for('/awesome', params: { 'apiver' => 'v1' })
       expect(subject.call(env)[1]['api.version']).to be_nil
@@ -36,10 +41,12 @@ describe Grape::Middleware::Versioner::Param do
 
   context 'with specified versions' do
     let(:options) { { versions: %w[v1 v2] } }
+
     it 'throws an error if a non-allowed version is specified' do
       env = Rack::MockRequest.env_for('/awesome', params: { 'apiver' => 'v3' })
       expect(catch(:error) { subject.call(env) }[:status]).to eq(404)
     end
+
     it 'allows versions that have been specified' do
       env = Rack::MockRequest.env_for('/awesome', params: { 'apiver' => 'v1' })
       expect(subject.call(env)[1]['api.version']).to eq('v1')
@@ -53,6 +60,7 @@ describe Grape::Middleware::Versioner::Param do
         version_options: { using: :header }
       }
     end
+
     it 'returns a 200 (matches the first version found)' do
       env = Rack::MockRequest.env_for('/awesome', params: {})
       expect(subject.call(env).first).to eq(200)
