@@ -2,7 +2,7 @@
 
 require 'spec_helper'
 
-describe Grape::Validations::CoerceValidator do
+describe Grape::Validations::Validators::CoerceValidator do
   subject do
     Class.new(Grape::API)
   end
@@ -23,7 +23,7 @@ describe Grape::Validations::CoerceValidator do
     end
 
     context 'i18n' do
-      after :each do
+      after do
         I18n.available_locales = %i[en]
         I18n.locale = :en
         I18n.default_locale = :en
@@ -31,9 +31,9 @@ describe Grape::Validations::CoerceValidator do
 
       it 'i18n error on malformed input' do
         I18n.available_locales = %i[en zh-CN]
-        I18n.load_path << File.expand_path('../zh-CN.yml', __FILE__)
+        I18n.load_path << File.expand_path('zh-CN.yml', __dir__)
         I18n.reload!
-        I18n.locale = 'zh-CN'.to_sym
+        I18n.locale = :'zh-CN'
         subject.params do
           requires :age, type: Integer
         end
@@ -48,7 +48,7 @@ describe Grape::Validations::CoerceValidator do
 
       it 'gives an english fallback error when default locale message is blank' do
         I18n.available_locales = %i[en pt-BR]
-        I18n.locale = 'pt-BR'.to_sym
+        I18n.locale = :'pt-BR'
         subject.params do
           requires :age, type: Integer
         end
@@ -83,10 +83,11 @@ describe Grape::Validations::CoerceValidator do
       context 'on custom coercion rules' do
         before do
           subject.params do
-            requires :a, types: { value: [Boolean, String], message: 'type cast is invalid' }, coerce_with: (lambda do |val|
-              if val == 'yup'
+            requires :a, types: { value: [Grape::API::Boolean, String], message: 'type cast is invalid' }, coerce_with: (lambda do |val|
+              case val
+              when 'yup'
                 true
-              elsif val == 'false'
+              when 'false'
                 0
               else
                 val
@@ -170,9 +171,9 @@ describe Grape::Validations::CoerceValidator do
           expect(last_response.body).to eq('BigDecimal 45.1')
         end
 
-        it 'Boolean' do
+        it 'Grape::API::Boolean' do
           subject.params do
-            requires :boolean, type: Boolean
+            requires :boolean, type: Grape::API::Boolean
           end
           subject.post '/boolean' do
             params[:boolean]
@@ -369,9 +370,9 @@ describe Grape::Validations::CoerceValidator do
         end
       end
 
-      it 'Boolean' do
+      it 'Grape::API::Boolean' do
         subject.params do
-          requires :boolean, type: Boolean
+          requires :boolean, type: Grape::API::Boolean
         end
         subject.get '/boolean' do
           params[:boolean].class
@@ -650,7 +651,7 @@ describe Grape::Validations::CoerceValidator do
 
       it 'parses parameters with Array[Array[String]] type and coerce_with' do
         subject.params do
-          requires :values, type: Array[Array[String]], coerce_with: ->(val) { val.is_a?(String) ? [val.split(/,/).map(&:strip)] : val }
+          requires :values, type: Array[Array[String]], coerce_with: ->(val) { val.is_a?(String) ? [val.split(',').map(&:strip)] : val }
         end
         subject.post '/coerce_nested_strings' do
           params[:values]
@@ -706,6 +707,44 @@ describe Grape::Validations::CoerceValidator do
         expect(JSON.parse(last_response.body)).to eq([1, 1, 1, 1])
       end
 
+      context 'Array type and coerce_with should' do
+        before do
+          subject.params do
+            optional :arr, type: Array, coerce_with: (lambda do |val|
+              if val.nil?
+                []
+              else
+                val
+              end
+            end)
+          end
+          subject.get '/' do
+            params[:arr].class.to_s
+          end
+        end
+
+        it 'coerce nil value to array' do
+          get '/', arr: nil
+
+          expect(last_response.status).to eq(200)
+          expect(last_response.body).to eq('Array')
+        end
+
+        it 'not coerce missing field' do
+          get '/'
+
+          expect(last_response.status).to eq(200)
+          expect(last_response.body).to eq('NilClass')
+        end
+
+        it 'coerce array as array' do
+          get '/', arr: []
+
+          expect(last_response.status).to eq(200)
+          expect(last_response.body).to eq('Array')
+        end
+      end
+
       it 'uses parse where available' do
         subject.params do
           requires :ints, type: Array, coerce_with: JSON do
@@ -754,13 +793,52 @@ describe Grape::Validations::CoerceValidator do
         expect(last_response.body).to eq('3')
       end
 
+      context 'Integer type and coerce_with should' do
+        before do
+          subject.params do
+            optional :int, type: Integer, coerce_with: (lambda do |val|
+              if val.nil?
+                0
+              else
+                val.to_i
+              end
+            end)
+          end
+          subject.get '/' do
+            params[:int].class.to_s
+          end
+        end
+
+        it 'coerce nil value to integer' do
+          get '/', int: nil
+
+          expect(last_response.status).to eq(200)
+          expect(last_response.body).to eq('Integer')
+        end
+
+        it 'not coerce missing field' do
+          get '/'
+
+          expect(last_response.status).to eq(200)
+          expect(last_response.body).to eq('NilClass')
+        end
+
+        it 'coerce integer as integer' do
+          get '/', int: 1
+
+          expect(last_response.status).to eq(200)
+          expect(last_response.body).to eq('Integer')
+        end
+      end
+
       context 'Integer type and coerce_with potentially returning nil' do
         before do
           subject.params do
             requires :int, type: Integer, coerce_with: (lambda do |val|
-              if val == '0'
+              case val
+              when '0'
                 nil
-              elsif val.match?(/^-?\d+$/)
+              when /^-?\d+$/
                 val.to_i
               else
                 val
@@ -940,11 +1018,9 @@ describe Grape::Validations::CoerceValidator do
     end
 
     context 'multiple types' do
-      Boolean = Grape::API::Boolean
-
       it 'coerces to first possible type' do
         subject.params do
-          requires :a, types: [Boolean, Integer, String]
+          requires :a, types: [Grape::API::Boolean, Integer, String]
         end
         subject.get '/' do
           params[:a].class.to_s
@@ -965,7 +1041,7 @@ describe Grape::Validations::CoerceValidator do
 
       it 'fails when no coercion is possible' do
         subject.params do
-          requires :a, types: [Boolean, Integer]
+          requires :a, types: [Grape::API::Boolean, Integer]
         end
         subject.get '/' do
           params[:a].class.to_s
@@ -1124,10 +1200,11 @@ describe Grape::Validations::CoerceValidator do
       context 'custom coercion rules' do
         before do
           subject.params do
-            requires :a, types: [Boolean, String], coerce_with: (lambda do |val|
-              if val == 'yup'
+            requires :a, types: [Grape::API::Boolean, String], coerce_with: (lambda do |val|
+              case val
+              when 'yup'
                 true
-              elsif val == 'false'
+              when 'false'
                 0
               else
                 val
