@@ -4,6 +4,6 @@ require 'spec_helper'
 
 describe Grape::Json do
   it 'uses multi_json' do
-    expect(Grape::Json).to eq(::MultiJson)
+    expect(described_class).to eq(::MultiJson)
   end
 end
