@@ -5,12 +5,21 @@ $LOAD_PATH.unshift(File.join(File.dirname(__FILE__), '..', 'lib'))
 $LOAD_PATH.unshift(File.join(File.dirname(__FILE__), 'support'))
 
 require 'grape'
+require 'test_prof/recipes/rspec/let_it_be'
+
+class NullAdapter
+  def begin_transaction; end
+
+  def rollback_transaction; end
+end
+
+TestProf::BeforeAll.adapter = NullAdapter.new
 
 require 'rubygems'
 require 'bundler'
 Bundler.require :default, :test
 
-Dir["#{File.dirname(__FILE__)}/support/*.rb"].each do |file|
+Dir["#{File.dirname(__FILE__)}/support/*.rb"].sort.each do |file|
   require file
 end
 
@@ -27,7 +36,8 @@ RSpec.configure do |config|
   config.filter_run_when_matching :focus
   config.warnings = true
 
-  config.before(:each) { Grape::Util::InheritableSetting.reset_global! }
+  config.before(:all) { Grape::Util::InheritableSetting.reset_global! }
+  config.before { Grape::Util::InheritableSetting.reset_global! }
 
   # Enable flags like --only-failures and --next-failure
   config.example_status_persistence_file_path = '.rspec_status'
